@@ -1,6 +1,6 @@
 globalVariables(c(
   "X1", "X2", "X3", "word", "code", "category", "texts",
-  "i", "j", "x", "Var1", "Var2", "value",
-  ".ndocs", ".nterm", ".document_total",
+  "i", "j", "x", "Var1", "Var2", "value", "out",
+  ".ndocs", ".nterm", ".document_total", "new_groups",
   "tf", "idf", "sentiments", "document", "term"
 ))
