@@ -32,7 +32,7 @@ unnest_ptb <- function(
   collapse = NULL,
   ...
 ){
-  format <- match.arg(format)
+  format <- arg_match(format)
   unnest_tokens(tbl,
                 !! enquo(output),
                 !! enquo(input),
